{ config, pkgs, ... }:

{
  imports =
    [
      ../../base.nix
      ../../common/metrics-exporters.nix
      ./hardware-configuration.nix
      ./backup.nix
      ./exports.nix
      ./filesystems.nix

      ./services/calibre.nix
      ./services/fancontrol.nix
      ./services/jellyfin.nix
      ./services/kanidm.nix
      ./services/komga.nix
      ./services/nextcloud.nix
      ./services/nginx
      ./services/podgrab.nix
      ./services/postgres.nix
      ./services/snappymail.nix
      ./services/timemachine.nix
  ];

  networking = {
    hostName = "voyager";
    bridges.br0.interfaces = [ "eno1" ];
    interfaces.br0.useDHCP = false;
    interfaces.br0.ipv4.addresses = [
      { address = "192.168.10.165"; prefixLength = 24; }
    ];

    hostId = "8e84b235";
    defaultGateway = "192.168.10.1";
  };

  sops.defaultSopsFile = ../../secrets/voyager/voyager.yaml;

  environment.variables = { EDITOR = "vim"; };
  environment.systemPackages = with pkgs; [
    zfs
  ];

  virtualisation.docker.enable = true;
  virtualisation.oci-containers.backend = "docker";

  users.users."amalieem" = {
    isNormalUser = true;
    home = "/home/amalieem";
    openssh.authorizedKeys.keys = [
      "ssh-ed25519 AAAAC3NzaC1lZDI1NTE5AAAAID7e+BAoXIFmTeeBYAVImQAcyx6SCoYCErA7h16OGL70 amalieem@wentworth"
    ];
  };

  system.stateVersion = "22.11";
}

